@@ -38,7 +38,10 @@ from .error import Error
 log = logging.getLogger(__name__)
 
 class JSONAPIError(Error):
-    '''Raised if for any JSON API errors.'''
+    '''Raised if for any JSON API errors.  The first argument to this
+    exception is the 401 response received from the web server.
+
+    '''
 
 class UnauthenticatedError(Error):
     '''Raised when a request fails with HTTP status code 401.'''
@@ -54,7 +57,7 @@ def get(resource, **kwargs):
     except requests.exceptions.RequestException as e:
         raise JSONAPIError('requests.get exception.') from e
     if r.status_code == 401:
-        raise UnauthenticatedError()
+        raise UnauthenticatedError(r)
     if r.status_code < 200 or r.status_code > 299:
         if log.getEffectiveLevel() <= logging.DEBUG:
             log.exception('HTTP GET status code %s.  Keyword args: %s',
@@ -81,7 +84,7 @@ def put(resource, json_data, **kwargs):
     except requests.exceptions.RequestException as e:
         raise JSONAPIError('requests.put exception.') from e
     if r.status_code == 401:
-        raise UnauthenticatedError()
+        raise UnauthenticatedError(r)
     if not 200 <= r.status_code <= 299:
         if log.getEffectiveLevel() <= logging.DEBUG:
             log.exception('HTTP PUT status code %s.  '
@@ -109,7 +112,7 @@ def post(resource, json_data, **kwargs):
     except requests.exceptions.RequestException as e:
         raise JSONAPIError('requests.post exception.') from e
     if r.status_code == 401:
-        raise UnauthenticatedError()
+        raise UnauthenticatedError(r)
     if not 200 <= r.status_code <= 299:
         if log.getEffectiveLevel() <= logging.DEBUG:
             log.exception('HTTP POST status code %s.  '
@@ -133,7 +136,7 @@ def delete(resource, **kwargs):
     except requests.exceptions.RequestException as e:
         raise JSONAPIError('requests.delete exception.') from e
     if r.status_code == 401:
-        raise UnauthenticatedError()
+        raise UnauthenticatedError(r)
     if r.status_code < 200 or r.status_code > 299:
         if log.getEffectiveLevel() <= logging.DEBUG:
             log.exception('HTTP DELETE status code %s.  Keyword args: %s',
